# Changelog

## [0.4.0](https://github.com/61418/elhaz/compare/v0.3.0...v0.4.0) (2026-03-25)


### Features

* Added a daemon status command. ([36ae37b](https://github.com/61418/elhaz/commit/36ae37b253f915c166209c9c8f0c64103ef2d394))
* Added a daemon status command. ([575ad8b](https://github.com/61418/elhaz/commit/575ad8bd4eeee8ef2ac5e98783eb25e3c306a403))

## [0.3.0](https://github.com/61418/elhaz/compare/v0.2.0...v0.3.0) (2026-03-25)


### Features

* Extending --obscure flag to whoami ([4aa37a1](https://github.com/61418/elhaz/commit/4aa37a180a7a2ee1a7305eb5d45f0105c204f2ec))
* Extending --obscure flag to whoami ([a130bd3](https://github.com/61418/elhaz/commit/a130bd3628176ca76a90158d1796500b4aa1ddd7))

## [0.2.0](https://github.com/61418/elhaz/compare/v0.1.8...v0.2.0) (2026-03-25)


### Features

* Adding --obscure flat to config get and daemon export ([4bb45ac](https://github.com/61418/elhaz/commit/4bb45ac370fe4613ef93c716ece9d2337f64b0bc))
* Adding --obscure flat to config get and export ([48b93cb](https://github.com/61418/elhaz/commit/48b93cb6b6cbcd09abf3061bbc9b01fb6337f0d7))

## [0.1.8](https://github.com/61418/elhaz/compare/v0.1.7...v0.1.8) (2026-03-25)


### Documentation

* Remove unicode characters from docs. ([f08494c](https://github.com/61418/elhaz/commit/f08494c5607a86c893cc525e07df0dbc1eebf8d4))
* Remove unicode characters from docs. ([02c707b](https://github.com/61418/elhaz/commit/02c707b8685b2de33a1406131bd9d283bbe47eaa))

## [0.1.7](https://github.com/61418/elhaz/compare/v0.1.6...v0.1.7) (2026-03-24)


### Documentation

* Refining Concepts docs and project description. ([949e7f3](https://github.com/61418/elhaz/commit/949e7f39ae1d7c17809f8638939a72dece1e1378))
* Refining Concepts docs and project description. ([bda5ddc](https://github.com/61418/elhaz/commit/bda5ddc17802b78c69eb09c5db3597f5d1b9a8ae))

## [0.1.6](https://github.com/61418/elhaz/compare/v0.1.5...v0.1.6) (2026-03-22)


### Documentation

* Updated header image. ([bf50e38](https://github.com/61418/elhaz/commit/bf50e381322ffd73416bdafc45a015afbdc03f2d))
* Updated header image. ([bf4256f](https://github.com/61418/elhaz/commit/bf4256ffb710a8fd92480d8e6f3ca9ac5add6f6c))

## [0.1.5](https://github.com/61418/elhaz/compare/v0.1.4...v0.1.5) (2026-03-22)


### Documentation

* README beautification. ([aee07a6](https://github.com/61418/elhaz/commit/aee07a61f3118abef4dddab245a17d31997f6131))
* README beautification. ([1b6e2a8](https://github.com/61418/elhaz/commit/1b6e2a83ccbc57be29ddb0078c0d9302d4b6019a))

## [0.1.4](https://github.com/61418/elhaz/compare/v0.1.3...v0.1.4) (2026-03-22)


### Bug Fixes

* Fixing pyproject.toml. ([fff3624](https://github.com/61418/elhaz/commit/fff3624fb206479f47b50928899bde9ffd56481c))
* Fixing pyproject.toml. ([7c7f038](https://github.com/61418/elhaz/commit/7c7f038739ff0f1275099ac2ae3cdd2d7482ce46))

## [0.1.3](https://github.com/61418/elhaz/compare/v0.1.2...v0.1.3) (2026-03-22)


### Documentation

* Adding classifiers to pyproject.toml. ([ef06141](https://github.com/61418/elhaz/commit/ef061414a7fdc2fe703078a0c34b2cd7c9e5325b))
* Adding classifiers to pyproject.toml. ([38e77c5](https://github.com/61418/elhaz/commit/38e77c52783cc2a92a00aed71d8bae046def239f))

## [0.1.2](https://github.com/61418/elhaz/compare/v0.1.1...v0.1.2) (2026-03-22)


### Documentation

* Updating quickstart link. ([d552946](https://github.com/61418/elhaz/commit/d552946f9af2ae1e671b6e2ee92f12cda158bc44))
* Updating quickstart link. ([fa42ed9](https://github.com/61418/elhaz/commit/fa42ed95eaab844b5d8ff323c952fc1c9b475c39))

## [0.1.1](https://github.com/61418/elhaz/compare/v0.1.0...v0.1.1) (2026-03-22)


### Documentation

* Updated README and pyproject.toml and index.html ([d336dc8](https://github.com/61418/elhaz/commit/d336dc883205f5a2b37815133224ea4149621515))
* Updated README and pyproject.toml and index.html ([355f06c](https://github.com/61418/elhaz/commit/355f06cb31d94d86f2035485d386819a127948fa))

## 0.1.0 (2026-03-22)


### Documentation

* Updated README and pyproject.toml and index.html ([d336dc8](https://github.com/61418/elhaz/commit/d336dc883205f5a2b37815133224ea4149621515))
* Updated README and pyproject.toml and index.html ([355f06c](https://github.com/61418/elhaz/commit/355f06cb31d94d86f2035485d386819a127948fa))
